#[non_exhaustive]pub struct Region {
pub target_offset: u64,
pub length: u32,
pub source: PartSource,
pub expected: PartExpected,
}Expand description
One contiguous range of bytes the patch writes into a target file.
#[non_exhaustive]: per-region diagnostic fields (chunk index of origin,
source patch index for provenance) may be added.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_offset: u64First byte offset within the target file that this region writes.
length: u32Length of the region in bytes.
source: PartSourceWhere the bytes come from.
expected: PartExpectedWhat the post-write content should be (size-only by default).
Implementations