pub enum SqpkFileOperation {
AddFile,
RemoveAll,
DeleteFile,
MakeDirTree,
}Expand description
Operation byte of a SQPK F command.
Variants
AddFile
A — add or overwrite a file with the inline block payload.
RemoveAll
R — remove all files in the expansion folder except a keep-list.
DeleteFile
D — delete a single file.
MakeDirTree
M — create a directory tree.